Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(632)

Unified Diff: net/http/http_server_properties_impl.h

Issue 1860343002: SHP 1: Change SupportsSpdy dict to use SchemeHostPort as the key. No change to Pref data. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/http/http_server_properties_impl.h
diff --git a/net/http/http_server_properties_impl.h b/net/http/http_server_properties_impl.h
index d6686733db1f75fe187201d2c908590aa563021a..fb11e9f67762d0e622b070518634ebe78da20dd0 100644
--- a/net/http/http_server_properties_impl.h
+++ b/net/http/http_server_properties_impl.h
@@ -79,9 +79,10 @@ class NET_EXPORT HttpServerPropertiesImpl
base::WeakPtr<HttpServerProperties> GetWeakPtr() override;
void Clear() override;
- bool SupportsRequestPriority(const HostPortPair& server) override;
- bool GetSupportsSpdy(const HostPortPair& server) override;
- void SetSupportsSpdy(const HostPortPair& server, bool support_spdy) override;
+ bool SupportsRequestPriority(const url::SchemeHostPort& server) override;
+ bool GetSupportsSpdy(const url::SchemeHostPort& server) override;
+ void SetSupportsSpdy(const url::SchemeHostPort& server,
+ bool support_spdy) override;
bool RequiresHTTP11(const HostPortPair& server) override;
void SetHTTP11Required(const HostPortPair& server) override;
void MaybeForceHTTP11(const HostPortPair& server,
@@ -134,9 +135,9 @@ class NET_EXPORT HttpServerPropertiesImpl
private:
friend class HttpServerPropertiesImplPeer;
- // |spdy_servers_map_| has flattened representation of servers (host, port)
- // that either support or not support SPDY protocol.
- typedef base::MRUCache<std::string, bool> SpdyServerHostPortMap;
+ // |spdy_servers_map_| has flattened representation of servers
+ // (scheme, host, port) that either support or not support SPDY protocol.
+ typedef base::MRUCache<std::string, bool> SpdyServerSchemeHostPortMap;
Ryan Hamilton 2016/04/06 19:16:08 How about just SpdyServerMap?
Zhongyi Shi 2016/04/07 00:31:18 Done.
typedef std::map<HostPortPair, HostPortPair> CanonicalHostMap;
typedef std::vector<std::string> CanonicalSufficList;
typedef std::set<HostPortPair> Http11ServerHostPortSet;
@@ -162,7 +163,7 @@ class NET_EXPORT HttpServerPropertiesImpl
void ExpireBrokenAlternateProtocolMappings();
void ScheduleBrokenAlternateProtocolMappingsExpiration();
- SpdyServerHostPortMap spdy_servers_map_;
+ SpdyServerSchemeHostPortMap spdy_servers_map_;
Http11ServerHostPortSet http11_servers_;
AlternativeServiceMap alternative_service_map_;

Powered by Google App Engine
This is Rietveld 408576698